==> org.jresearch.commons.gwt.flexess-1.0.5.jar: org/jresearch/commons/gwt/flexess/client/model/meta/PermissionTemplateModel.java <==
package org.jresearch.commons.gwt.flexess.client.model.meta;

import java.util.List;

import org.jresearch.commons.gwt.client.model.DomainNewModel;

public class PermissionTemplateModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String modelId;
	private List<AttributeTemplateModel> attributes;

	// constraint,
	// description,
	// operations,
	// protectedObject,
	// roles,

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("PermissionTemplateModel ["); //$NON-NLS-1$
		if (getModelId() != null) {
			builder.append("getModelId()=").append(getModelId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		if (getAttributes() != null) {
			builder.append("getAttributes()=").append(getAttributes()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the modelId
	 */
	public String getModelId() {
		return modelId;
	}

	/**
	 * @param modelId
	 *            the modelId to set
	 */
	public void setModelId(final String modelId) {
		this.modelId = modelId;
	}

	/**
	 * @return the attributes
	 */
	public List<AttributeTemplateModel> getAttributes() {
		return attributes;
	}

	/**
	 * @param attributes
	 *            the attributes to set
	 */
	public void setAttributes(final List<AttributeTemplateModel> attributes) {
		this.attributes = attributes;
	}

}

==> org.jresearch.commons.gwt.flexess-1.0.9.jar: org/jresearch/commons/gwt/flexess/client/model/meta/PermissionTemplateModel.java <==
package org.jresearch.commons.gwt.flexess.client.model.meta;

import java.util.List;

import org.jresearch.commons.gwt.shared.model.DomainNewModel;

public class PermissionTemplateModel extends DomainNewModel<String> {

	private static final long serialVersionUID = -5705542024857825838L;

	private String modelId;
	private List<AttributeTemplateModel> attributes;

	// constraint,
	// description,
	// operations,
	// protectedObject,
	// roles,

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		final StringBuilder builder = new StringBuilder();
		builder.append("PermissionTemplateModel ["); //$NON-NLS-1$
		if (getModelId() != null) {
			builder.append("getModelId()=").append(getModelId()).append(", "); //$NON-NLS-1$ //$NON-NLS-2$
		}
		if (getAttributes() != null) {
			builder.append("getAttributes()=").append(getAttributes()); //$NON-NLS-1$
		}
		builder.append("]"); //$NON-NLS-1$
		return builder.toString();
	}

	/**
	 * @return the modelId
	 */
	public String getModelId() {
		return modelId;
	}

	/**
	 * @param modelId
	 *            the modelId to set
	 */
	public void setModelId(final String modelId) {
		this.modelId = modelId;
	}

	/**
	 * @return the attributes
	 */
	public List<AttributeTemplateModel> getAttributes() {
		return attributes;
	}

	/**
	 * @param attributes
	 *            the attributes to set
	 */
	public void setAttributes(final List<AttributeTemplateModel> attributes) {
		this.attributes = attributes;
	}

}
